@@ -83,8 +83,8 @@ burden <- function(M, nI, nT, learning, weight_by = "instrument") {
     nI <- nInew
     M <- t(M)
   }
-  sum.i <- apply(M, 1, sum)
-  if (length(sum.i) > 1) {
+  sum.i <- apply(M, 1, sum, na.rm = TRUE)
+  if (length(sum.i) > 1 & length(which(is.na(sum.i))) != length(sum.i) ) {
     parts <- NULL
     if (learning == "continuous") {
       # arithmetical decay
