@@ -4,7 +4,7 @@
 #'
 #' @param D Data frame in a tidy format with the following columns: "Country", "Sector", "Year", "Instrument", "Target" and "covered". "covered" is a binary identificator of whether the portfolio space is covered by policy intervention (1) or not (0). The remaining columns identify the case. Notice that "Year" is a numeric value, while the remaining 4 case identifiers are factors.
 #' @param id A list with up to two elements, namely "Country", and "Year" indicating the specific identification characteristics of the portfolio(s) that must be processed. Defaults to NULL to process all portfolios.
-#' @param method A character vector containing the indices of similarity requested. Defaults to "all". The implemented indices of binary similarity are "jaccard" (), "
+#' @param method A character vector containing the indices of similarity requested. Defaults to "all". The implemented indices of binary similarity are "Jaccard", "Hamming" (Hamming distance), "Dice" (Sorensen & Dice), "Overlap" (Szymkiewicz and Simpson) and "Rand" (or Simple Matching Coefficient).
 #' @param return_all Logical indicating whether all possible combinations (countries and years of origin and destination) must be returned or only when they are different. Defaults to TRUE.
 #' @return A tidy dataset containing the portfolio identificators (Country, Sector and Year) plus the similarity measures and their values.
 #' @export
@@ -57,15 +57,21 @@ pp_similarity <- function(D, id = NULL, method = "all", return_all = TRUE) {
   all.methods <- c("Jaccard", "Hamming", "Dice", "Overlap", "Rand")
   all.methods.labels <- c("Similarity (Jaccard)", 
                           "Distance (Hamming)",
-                          "Similarity (S\u00f8rensen\u002DDice)",
-                          "Similarity (Szymkiewicz\u002DSimpson)",
+                          "Similarity (Sorensen Dice)",
+                          "Similarity (Szymkiewicz Simpson)",
                           "Similarity (Rand or Simple Matching Coefficient)")
   if (length(method) == 1) {
     if (method == "all") {
       methods <- all.methods
       methods.labels <- all.methods.labels
     } else {
-      stop("No valid method provided.")
+      which.methods <- which(all.methods %in% method)
+      if (length(which.methods) == 0) {
+        stop("No valid method provided.")
+      }
+      methods <- all.methods[which.methods]
+      methods.labels <- all.methods.labels[which.methods]
+      message(paste0("Using method: ", paste(methods, sep = "", collapse = ", ")))
     }
   }
   if (length(method) != 1) {
@@ -93,17 +99,17 @@ pp_similarity <- function(D, id = NULL, method = "all", return_all = TRUE) {
   O <- NULL
   O <- list()
   i <- 1
-  for (s in 1:nS) {
-    for (c in 1:nC) {
+  for (s in seq_len(nS)) {
+    for (c in seq_len(nC)) {
       message("Processing country: ", Countries[c], sep = "")
-      for (y in 1:nY) {
+      for (y in seq_len(nY)) {
         message("Processing year: ", Years[y], sep = "")
         P.origin <- P.full[c,s,y,,]
-        for (c.dest in 1:nC) {
-          for (y.dest in 1:nY) {
+        for (c.dest in seq_len(nC)) {
+          for (y.dest in seq_len(nY)) {
             P.destination <- P.full[c.dest,s,y.dest,,]
             similarity <- NULL
-            for (m in 1:nMethods) {
+            for (m in seq_len(nMethods)) {
               # Most formulas need the following:
               # ioid: cases where 1's are IN ORIGIN (io) and IN DESTINATION (id)
               # compared to cases NOT IN ORIGIN (nio) and/or NOT IN DESTINATION (nid)
@@ -162,7 +168,7 @@ pp_similarity <- function(D, id = NULL, method = "all", return_all = TRUE) {
   # Clean years for which some countries do not have data
   if (clean.years) {
     clean.countries <- as.character(D.years.n$Country[D.years.n$N < max(D.years.n$N)])
-    for (c in 1:length(clean.countries)) {
+    for (c in seq_len(length(clean.countries))) {
       message(paste0("Cleaning years from ", clean.countries[c]))
       extra.years <- as.vector(dplyr::filter(D.years.yn, Country == clean.countries[c] & N == 0)$Year)
       O <- O %>%
